@@ -59,10 +59,8 @@ class TaskHub():
     timeout = 600
     check_gap = 20
 
-    def __init__(self,back_end_url):
-        self.back_end_url = back_end_url
-
-        pass
+    def __init__(self,sync):
+        self.sync = sync
     
     def add(self,task:Task):
         """[summary]
@@ -170,28 +168,6 @@ class TaskHub():
                 t = time.time()
                 time.sleep(1)
  
-    def sync(self,task):
-        makelog("syncing...")
-        try:
-            r_data = self.req(task)
-        except :
-            makelog("sync: req 时发生异常：{}".format(traceback.format_exc()),1)
-            return False
-        else:
-            if r_data.get("suc"):
-                makelog("synced!", 4)
-                return True
-            else:
-                makelog("sync: 返回状态异常：{}".format(r_data))
-                return False
-
-    
-    @retry(tries=5,delay=1,backoff=1)
-    def req(self,task:Task):
-        r = requests.post(self.back_end_url,json=task.get_dict())
-        r.raise_for_status
-        return r.json()
-
     def get_lock(self):
         # makelog("getting lock ....")
         while self.lock:
